@@ -28,11 +28,10 @@
 
 #include "jobscheduler.h"
 #include "mailcommon_debug.h"
-namespace MailCommon
-{
-
+namespace MailCommon {
 ScheduledTask::ScheduledTask(const Akonadi::Collection &folder, bool immediate)
-    : mCurrentFolder(folder), mImmediate(immediate)
+    : mCurrentFolder(folder)
+    , mImmediate(immediate)
 {
 }
 
@@ -41,9 +40,11 @@ ScheduledTask::~ScheduledTask()
 }
 
 JobScheduler::JobScheduler(QObject *parent)
-    : QObject(parent), mTimer(this),
-      mPendingImmediateTasks(0),
-      mCurrentTask(nullptr), mCurrentJob(nullptr)
+    : QObject(parent)
+    , mTimer(this)
+    , mPendingImmediateTasks(0)
+    , mCurrentTask(nullptr)
+    , mCurrentJob(nullptr)
 {
     connect(&mTimer, &QTimer::timeout, this, &JobScheduler::slotRunNextJob);
     // No need to start the internal timer yet, we wait for a task to be scheduled
@@ -246,6 +247,4 @@ ScheduledJob::ScheduledJob(const Akonadi::Collection &folder, bool immediate)
 ScheduledJob::~ScheduledJob()
 {
 }
-
 }
-
