@@ -35,9 +35,7 @@ class QAbstractButton;
 class QRadioButton;
 class QStackedWidget;
 
-namespace MailCommon
-{
-
+namespace MailCommon {
 class SearchPatternEdit;
 
 /**
@@ -98,9 +96,7 @@ public:
      * QGroupBox, as usual.
      */
     explicit SearchPatternEdit(
-        QWidget *parent = nullptr,
-        SearchPatternEditOptions options = (SearchPatternEditOptions)(None),
-        SearchModeType modeType = StandardMode);
+        QWidget *parent = nullptr, SearchPatternEditOptions options = (SearchPatternEditOptions)(None), SearchModeType modeType = StandardMode);
 
     ~SearchPatternEdit();
 
@@ -147,11 +143,11 @@ private Q_SLOTS:
 
 private:
     void initLayout(SearchPatternEditOptions options, SearchModeType modeType);
-    MailCommon::SearchPattern *mPattern;
-    QRadioButton *mAllRBtn;
-    QRadioButton *mAnyRBtn;
-    QRadioButton *mAllMessageRBtn;
-    SearchRuleWidgetLister *mRuleLister;
+    MailCommon::SearchPattern *mPattern = nullptr;
+    QRadioButton *mAllRBtn = nullptr;
+    QRadioButton *mAnyRBtn = nullptr;
+    QRadioButton *mAllMessageRBtn = nullptr;
+    SearchRuleWidgetLister *mRuleLister = nullptr;
 };
 
 /**
@@ -197,7 +193,8 @@ public:
         CC,
         ReplyTo,
         Organization,
-        Date
+        Date,
+        Encryption
     };
 
     /**
@@ -271,11 +268,11 @@ private:
     void initFieldList(MailCommon::SearchPatternEdit::SearchPatternEditOptions options);
 
     QStringList mFilterFieldList;
-    KComboBox *mRuleField;
-    QStackedWidget *mFunctionStack;
-    QStackedWidget *mValueStack;
-    QPushButton *mAdd;
-    QPushButton *mRemove;
+    KComboBox *mRuleField = nullptr;
+    QStackedWidget *mFunctionStack = nullptr;
+    QStackedWidget *mValueStack = nullptr;
+    QPushButton *mAdd = nullptr;
+    QPushButton *mRemove = nullptr;
 };
 
 class SearchRuleWidgetLister : public KPIM::KWidgetLister
@@ -285,8 +282,7 @@ class SearchRuleWidgetLister : public KPIM::KWidgetLister
     friend class SearchPatternEdit;
 
 public:
-    explicit SearchRuleWidgetLister(QWidget *parent = nullptr,
-                                    SearchPatternEdit::SearchPatternEditOptions opt = (SearchPatternEdit::SearchPatternEditOptions)(SearchPatternEdit::None),
+    explicit SearchRuleWidgetLister(QWidget *parent = nullptr, SearchPatternEdit::SearchPatternEditOptions opt = (SearchPatternEdit::SearchPatternEditOptions)(SearchPatternEdit::None),
                                     SearchPatternEdit::SearchModeType modeType = SearchPatternEdit::StandardMode);
 
     virtual ~SearchRuleWidgetLister();
@@ -301,18 +297,17 @@ public Q_SLOTS:
     void slotRemoveWidget(QWidget *);
 
 protected:
-    void clearWidget(QWidget *aWidget) Q_DECL_OVERRIDE;
-    QWidget *createWidget(QWidget *parent) Q_DECL_OVERRIDE;
+    void clearWidget(QWidget *aWidget) override;
+    QWidget *createWidget(QWidget *parent) override;
 
 private:
     void reconnectWidget(SearchRuleWidget *w);
     void updateAddRemoveButton();
     void regenerateRuleListFromWidgets();
-    QList<MailCommon::SearchRule::Ptr> *mRuleList;
+    QList<MailCommon::SearchRule::Ptr> *mRuleList = nullptr;
     SearchPatternEdit::SearchPatternEditOptions mOptions;
     SearchPatternEdit::SearchModeType mTypeMode;
 };
-
 }
 
 #endif
